@@ -51,7 +51,7 @@ GtkWidget* any_scale_icon (const gchar *filename, gint width, gint height)
 }
 
 
-inline GtkWidget* scaled_icon (const gchar *filename)
+GtkWidget* scaled_icon (const gchar *filename)
 {
   return any_scale_icon (filename, icon_width, icon_height);
 }
